{-# LANGUAGE DeriveGeneric #-}
{-# LANGUAGE DuplicateRecordFields #-}
{-# LANGUAGE NamedFieldPuns #-}
{-# LANGUAGE OverloadedStrings #-}
{-# LANGUAGE RecordWildCards #-}
{-# LANGUAGE StrictData #-}
{-# LANGUAGE NoImplicitPrelude #-}
{-# OPTIONS_GHC -fno-warn-unused-imports #-}
{-# OPTIONS_GHC -fno-warn-unused-matches #-}

-- Derived from AWS service descriptions, licensed under Apache 2.0.

-- |
-- Module      : Amazonka.SWF.Types.RecordMarkerFailedEventAttributes
-- Copyright   : (c) 2013-2023 Brendan Hay
-- License     : Mozilla Public License, v. 2.0.
-- Maintainer  : Brendan Hay
-- Stability   : auto-generated
-- Portability : non-portable (GHC extensions)
module Amazonka.SWF.Types.RecordMarkerFailedEventAttributes where

import qualified Amazonka.Core as Core
import qualified Amazonka.Core.Lens.Internal as Lens
import qualified Amazonka.Data as Data
import qualified Amazonka.Prelude as Prelude
import Amazonka.SWF.Types.RecordMarkerFailedCause

-- | Provides the details of the @RecordMarkerFailed@ event.
--
-- /See:/ 'newRecordMarkerFailedEventAttributes' smart constructor.
data RecordMarkerFailedEventAttributes = RecordMarkerFailedEventAttributes'
  { -- | The marker\'s name.
    markerName :: Prelude.Text,
    -- | The cause of the failure. This information is generated by the system
    -- and can be useful for diagnostic purposes.
    --
    -- If @cause@ is set to @OPERATION_NOT_PERMITTED@, the decision failed
    -- because it lacked sufficient permissions. For details and example IAM
    -- policies, see
    -- <https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html Using IAM to Manage Access to Amazon SWF Workflows>
    -- in the /Amazon SWF Developer Guide/.
    cause :: RecordMarkerFailedCause,
    -- | The ID of the @DecisionTaskCompleted@ event corresponding to the
    -- decision task that resulted in the @RecordMarkerFailed@ decision for
    -- this cancellation request. This information can be useful for diagnosing
    -- problems by tracing back the chain of events leading up to this event.
    decisionTaskCompletedEventId :: Prelude.Integer
  }
  deriving (Prelude.Eq, Prelude.Read, Prelude.Show, Prelude.Generic)

-- |
-- Create a value of 'RecordMarkerFailedEventAttributes' with all optional fields omitted.
--
-- Use <https://hackage.haskell.org/package/generic-lens generic-lens> or <https://hackage.haskell.org/package/optics optics> to modify other optional fields.
--
-- The following record fields are available, with the corresponding lenses provided
-- for backwards compatibility:
--
-- 'markerName', 'recordMarkerFailedEventAttributes_markerName' - The marker\'s name.
--
-- 'cause', 'recordMarkerFailedEventAttributes_cause' - The cause of the failure. This information is generated by the system
-- and can be useful for diagnostic purposes.
--
-- If @cause@ is set to @OPERATION_NOT_PERMITTED@, the decision failed
-- because it lacked sufficient permissions. For details and example IAM
-- policies, see
-- <https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html Using IAM to Manage Access to Amazon SWF Workflows>
-- in the /Amazon SWF Developer Guide/.
--
-- 'decisionTaskCompletedEventId', 'recordMarkerFailedEventAttributes_decisionTaskCompletedEventId' - The ID of the @DecisionTaskCompleted@ event corresponding to the
-- decision task that resulted in the @RecordMarkerFailed@ decision for
-- this cancellation request. This information can be useful for diagnosing
-- problems by tracing back the chain of events leading up to this event.
newRecordMarkerFailedEventAttributes ::
  -- | 'markerName'
  Prelude.Text ->
  -- | 'cause'
  RecordMarkerFailedCause ->
  -- | 'decisionTaskCompletedEventId'
  Prelude.Integer ->
  RecordMarkerFailedEventAttributes
newRecordMarkerFailedEventAttributes
  pMarkerName_
  pCause_
  pDecisionTaskCompletedEventId_ =
    RecordMarkerFailedEventAttributes'
      { markerName =
          pMarkerName_,
        cause = pCause_,
        decisionTaskCompletedEventId =
          pDecisionTaskCompletedEventId_
      }

-- | The marker\'s name.
recordMarkerFailedEventAttributes_markerName :: Lens.Lens' RecordMarkerFailedEventAttributes Prelude.Text
recordMarkerFailedEventAttributes_markerName = Lens.lens (\RecordMarkerFailedEventAttributes' {markerName} -> markerName) (\s@RecordMarkerFailedEventAttributes' {} a -> s {markerName = a} :: RecordMarkerFailedEventAttributes)

-- | The cause of the failure. This information is generated by the system
-- and can be useful for diagnostic purposes.
--
-- If @cause@ is set to @OPERATION_NOT_PERMITTED@, the decision failed
-- because it lacked sufficient permissions. For details and example IAM
-- policies, see
-- <https://docs.aws.amazon.com/amazonswf/latest/developerguide/swf-dev-iam.html Using IAM to Manage Access to Amazon SWF Workflows>
-- in the /Amazon SWF Developer Guide/.
recordMarkerFailedEventAttributes_cause :: Lens.Lens' RecordMarkerFailedEventAttributes RecordMarkerFailedCause
recordMarkerFailedEventAttributes_cause = Lens.lens (\RecordMarkerFailedEventAttributes' {cause} -> cause) (\s@RecordMarkerFailedEventAttributes' {} a -> s {cause = a} :: RecordMarkerFailedEventAttributes)

-- | The ID of the @DecisionTaskCompleted@ event corresponding to the
-- decision task that resulted in the @RecordMarkerFailed@ decision for
-- this cancellation request. This information can be useful for diagnosing
-- problems by tracing back the chain of events leading up to this event.
recordMarkerFailedEventAttributes_decisionTaskCompletedEventId :: Lens.Lens' RecordMarkerFailedEventAttributes Prelude.Integer
recordMarkerFailedEventAttributes_decisionTaskCompletedEventId = Lens.lens (\RecordMarkerFailedEventAttributes' {decisionTaskCompletedEventId} -> decisionTaskCompletedEventId) (\s@RecordMarkerFailedEventAttributes' {} a -> s {decisionTaskCompletedEventId = a} :: RecordMarkerFailedEventAttributes)

instance
  Data.FromJSON
    RecordMarkerFailedEventAttributes
  where
  parseJSON =
    Data.withObject
      "RecordMarkerFailedEventAttributes"
      ( \x ->
          RecordMarkerFailedEventAttributes'
            Prelude.<$> (x Data..: "markerName")
            Prelude.<*> (x Data..: "cause")
            Prelude.<*> (x Data..: "decisionTaskCompletedEventId")
      )

instance
  Prelude.Hashable
    RecordMarkerFailedEventAttributes
  where
  hashWithSalt
    _salt
    RecordMarkerFailedEventAttributes' {..} =
      _salt
        `Prelude.hashWithSalt` markerName
        `Prelude.hashWithSalt` cause
        `Prelude.hashWithSalt` decisionTaskCompletedEventId

instance
  Prelude.NFData
    RecordMarkerFailedEventAttributes
  where
  rnf RecordMarkerFailedEventAttributes' {..} =
    Prelude.rnf markerName
      `Prelude.seq` Prelude.rnf cause
      `Prelude.seq` Prelude.rnf decisionTaskCompletedEventId
